==> hinemos_src-4.1.3.tar.gz: HinemosClient/src_jobmanagement/com/clustercontrol/jobmanagement/viewer/JobTreeContentProvider.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.jobmanagement.viewer;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

import com.clustercontrol.ws.jobmanagement.JobTreeItem;

/**
 * ジョブツリー用コンポジットのツリービューア用のITreeContentProviderクラスです。
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class JobTreeContentProvider implements ITreeContentProvider {

	/**
	 * ジョブツリーアイテムの要素(子のジョブツリーアイテム)を返します。
	 * 
	 * @param inputElement ジョブツリーアイテム
	 * @return ジョブツリーアイテムの配列
	 * 
	 * @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
	 */
	@Override
	public Object[] getElements(Object inputElement) {
		return getChildren(inputElement);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#dispose()
	 */
	@Override
	public void dispose() {
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
	 */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
	}

	/**
	 * ジョブツリーアイテムの子のジョブツリーアイテムを返します。
	 * 
	 * @param parentElement ジョブツリーアイテム
	 * @return ジョブツリーアイテムの配列
	 * 
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getChildren(java.lang.Object)
	 */
	@Override
	public Object[] getChildren(Object parentElement) {
		return ((JobTreeItem) parentElement).getChildren().toArray();
	}

	/**
	 * ジョブツリーアイテムの親ジョブツリーアイテムを返します。
	 * 
	 * @param element 親ジョブツリーアイテム
	 * 
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getParent(java.lang.Object)
	 */
	@Override
	public Object getParent(Object element) {
		return ((JobTreeItem) element).getParent();
	}

	/**
	 * ジョブツリーアイテムが子のジョブツリーアイテムを持っているかを返します。
	 * 
	 * @param element ジョブツリーアイテム
	 * @return true：子がある、false：子がない
	 * 
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#hasChildren(java.lang.Object)
	 */
	@Override
	public boolean hasChildren(Object element) {
		return ((JobTreeItem) element).getChildren().size() > 0;
	}

}

==> hinemos_src-5.0.1.tar.gz: HinemosClient/src_jobmanagement/com/clustercontrol/jobmanagement/viewer/JobTreeContentProvider.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.jobmanagement.viewer;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.eclipse.jface.viewers.ITreeContentProvider;
import org.eclipse.jface.viewers.Viewer;

import com.clustercontrol.ws.jobmanagement.JobTreeItem;

/**
 * ジョブツリー用コンポジットのツリービューア用のITreeContentProviderクラスです。
 *
 * @version 1.0.0
 * @since 1.0.0
 */
public class JobTreeContentProvider implements ITreeContentProvider {

	/**
	 * ジョブツリーアイテムの要素(子のジョブツリーアイテム)を返します。
	 *
	 * @param inputElement ジョブツリーアイテム
	 * @return ジョブツリーアイテムの配列
	 *
	 * @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
	 */
	@Override
	public Object[] getElements(Object inputElement) {
		return getChildren(inputElement);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#dispose()
	 */
	@Override
	public void dispose() {
	}

	/* (non-Javadoc)
	 * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer, java.lang.Object, java.lang.Object)
	 */
	@Override
	public void inputChanged(Viewer viewer, Object oldInput, Object newInput) {
	}

	/**
	 * ジョブツリーアイテムの子のジョブツリーアイテムを返します。
	 *
	 * @param parentElement ジョブツリーアイテム
	 * @return ジョブツリーアイテムの配列
	 *
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getChildren(java.lang.Object)
	 */
	@Override
	public Object[] getChildren(Object parentElement) {
		List<JobTreeItem> ret = null;
		if(parentElement instanceof ArrayList<?>) {
			ArrayList<?> list = (ArrayList<?>)parentElement;
			ret = ((JobTreeItem)list.get(0)).getChildren();
		} else if (parentElement instanceof JobTreeItem){
			ret = ((JobTreeItem)parentElement).getChildren();
		}
		Collections.sort(ret, new Comparator<JobTreeItem>(){
			@Override
			public int compare(JobTreeItem o1, JobTreeItem o2) {
				String s1 = o1.getData().getId();
				String s2 = o2.getData().getId();
				return s1.compareTo(s2);
			}
		});
		return ret.toArray();
	}
	
	
	/**
	 * ジョブツリーアイテムの親ジョブツリーアイテムを返します。
	 *
	 * @param element 親ジョブツリーアイテム
	 *
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#getParent(java.lang.Object)
	 */
	@Override
	public Object getParent(Object element) {
		return ((JobTreeItem) element).getParent();
	}

	/**
	 * ジョブツリーアイテムが子のジョブツリーアイテムを持っているかを返します。
	 *
	 * @param element ジョブツリーアイテム
	 * @return true：子がある、false：子がない
	 *
	 * @see org.eclipse.jface.viewers.ITreeContentProvider#hasChildren(java.lang.Object)
	 */
	@Override
	public boolean hasChildren(Object element) {
		return ((JobTreeItem) element).getChildren().size() > 0;
	}

}
